==> jboss-eap-7.0.4-src.zip: jboss-eap-7.0-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/weld/ejb/inheritance/InjectingCDIBean.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.weld.ejb.inheritance;

import javax.inject.Inject;

/**
 * @author Stuart Douglas
 */
public class InjectingCDIBean {

    @Inject
    private AbstractBaseClass inheritingBean;

    @Inject
    private ParentInterface parentInterface;

    public String sayHello() {
        return inheritingBean.sayHello();
    }

    public String sayGoodbye() {
        return inheritingBean.sayGoodbye();
    }

    public String callInterfaceMethod() {
        return parentInterface.interfaceMethod();
    }

}

==> jboss-eap-8.0.8-src.zip: jboss-eap-8.0-src/testsuite/integration/basic/src/test/java/org/jboss/as/test/integration/weld/ejb/inheritance/InjectingCDIBean.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.as.test.integration.weld.ejb.inheritance;

import jakarta.inject.Inject;

/**
 * @author Stuart Douglas
 */
public class InjectingCDIBean {

    @Inject
    private AbstractBaseClass inheritingBean;

    @Inject
    private ParentInterface parentInterface;

    public String sayHello() {
        return inheritingBean.sayHello();
    }

    public String sayGoodbye() {
        return inheritingBean.sayGoodbye();
    }

    public String callInterfaceMethod() {
        return parentInterface.interfaceMethod();
    }

}
